@@ -9,6 +9,7 @@ import sys
 import os
 import numpy as np
 import matplotlib.pyplot as plt
+from matplotlib import cm
 from mpl_toolkits.axes_grid1.inset_locator import inset_axes
 import seaborn as sns
 
@@ -269,7 +270,7 @@ def plot_thresh_obs(adata, thresholds, bins=40, axes=None, save_to=None, verbose
     if save_to:
         if verbose:
             print("Saving threshold plot to {}".format(save_to))
-        fig.savefig(save_to)
+        fig.savefig(save_to, dpi=200)
     elif not axes:
         return fig
 
@@ -554,10 +555,19 @@ def dropkick(
 
     # 4) use model to assign scores and labels to original adata
     print("Assigning scores and labels")
+    if "dropkick_score" in a.obs.columns:
+        print("Warning: Overwriting existing dropkick scores in .obs")
+        a.obs.drop(columns=["dropkick_score"], inplace=True)
     adata.obs.loc[a.obs_names, "dropkick_score"] = rc_.predict_proba(X)[:, 1]
     adata.obs.dropkick_score.fillna(0, inplace=True)  # fill ignored cells with zeros
+    if "dropkick_label" in a.obs.columns:
+        print("Warning: Overwriting existing dropkick labels in .obs")
+        a.obs.drop(columns=["dropkick_label"], inplace=True)
     adata.obs.loc[a.obs_names, "dropkick_label"] = rc_.predict(X)
     adata.obs.dropkick_label.fillna(0, inplace=True)  # fill ignored cells with zeros
+    adata.obs.dropkick_label = adata.obs.dropkick_label.astype(bool).astype(
+        "category"
+    )  # convert to categorical dtype
     for metric in metrics:
         adata.obs.loc[a.obs_names, metric] = a.obs[metric]
         adata.obs[metric].fillna(0, inplace=True)  # fill ignored cells with zeros
@@ -630,6 +640,7 @@ def coef_plot(adata, axes=None, save_to=None, verbose=True):
         plot of CV scores (mean +/- SEM) and coefficient values (coef_path) versus
         log(lambda_path). includes indicator of chosen lambda value.
     """
+    cmap = cm.get_cmap("coolwarm")
     if save_to or not axes:
         fig, axes = plt.subplots(nrows=2, ncols=1, figsize=(7, 7), sharex=True)
     # plot coefficient values versus log(lambda) on top axis
@@ -638,6 +649,7 @@ def coef_plot(adata, axes=None, save_to=None, verbose=True):
         np.log(adata.uns["dropkick_args"]["lambda_path"]),
         adata.uns["dropkick_args"]["coef_path"],
         alpha=0.5,
+        linewidth=2,
     )
     axes[0].tick_params(axis="both", which="major", labelsize=12)
     # plot vertical line at chosen lambda value and add to legend
@@ -646,6 +658,7 @@ def coef_plot(adata, axes=None, save_to=None, verbose=True):
         label=None,
         color="k",
         ls="--",
+        linewidth=2,
     )
     # plot total model sparsity and top three genes by coefficient value
     # get range of values for positioning text
@@ -692,7 +705,7 @@ def coef_plot(adata, axes=None, save_to=None, verbose=True):
             .nsmallest(3)
             .index[x],
             fontsize=12,
-            color="r",
+            color=cmap(1.0),
         )
         for x in range(3)
     ]
@@ -702,7 +715,8 @@ def coef_plot(adata, axes=None, save_to=None, verbose=True):
         np.log(adata.uns["dropkick_args"]["lambda_path"]),
         -2 * adata.uns["dropkick_args"]["cv_mean_score"],
         label="Mean Deviance",
-        color="b",
+        color=cmap(0.0),
+        linewidth=2,
     )
     axes[1].fill_between(
         np.log(adata.uns["dropkick_args"]["lambda_path"]),
@@ -710,8 +724,8 @@ def coef_plot(adata, axes=None, save_to=None, verbose=True):
         - 2 * adata.uns["dropkick_args"]["cv_standard_error"],
         y2=(-2 * adata.uns["dropkick_args"]["cv_mean_score"])
         + 2 * adata.uns["dropkick_args"]["cv_standard_error"],
-        color="b",
-        alpha=0.2,
+        color=cmap(0.0),
+        alpha=0.3,
         label="Deviance SEM",
     )
     # plot vertical line at chosen lambda value and add to legend
@@ -722,6 +736,7 @@ def coef_plot(adata, axes=None, save_to=None, verbose=True):
         ),
         color="k",
         ls="--",
+        linewidth=2,
     )
     axes[1].set_xlabel("Log (lambda)", fontsize=12)
     axes[1].set_ylabel("Binomial Deviance", fontsize=12)
@@ -732,7 +747,7 @@ def coef_plot(adata, axes=None, save_to=None, verbose=True):
     if save_to:
         if verbose:
             print("Saving coefficient plot to {}".format(save_to))
-        fig.savefig(save_to)
+        fig.savefig(save_to, dpi=200)
     elif axes is None:
         return fig
 
@@ -788,7 +803,7 @@ def score_plot(
             adata.uns["dropkick_thresholds"][metrics[0]]["thresh"], np.ndarray
         ):
             [
-                plt.axvline(_x, linestyle="--", color="k")
+                plt.axvline(_x, linestyle="--", color="k", linewidth=2)
                 for _x in adata.uns["dropkick_thresholds"][metrics[0]]["thresh"]
             ]
         else:
@@ -796,13 +811,14 @@ def score_plot(
                 adata.uns["dropkick_thresholds"][metrics[0]]["thresh"],
                 linestyle="--",
                 color="k",
+                linewidth=2,
             )
     if metrics[1] in adata.uns["dropkick_thresholds"]:
         if isinstance(
             adata.uns["dropkick_thresholds"][metrics[1]]["thresh"], np.ndarray
         ):
             [
-                plt.axhline(_x, linestyle="--", color="k")
+                plt.axhline(_x, linestyle="--", color="k", linewidth=2)
                 for _x in adata.uns["dropkick_thresholds"][metrics[1]]["thresh"]
             ]
         else:
@@ -810,6 +826,7 @@ def score_plot(
                 adata.uns["dropkick_thresholds"][metrics[1]]["thresh"],
                 linestyle="--",
                 color="k",
+                linewidth=2,
             )
     # change focus to x margin plot to continue threshold line
     if metrics[0] in adata.uns["dropkick_thresholds"]:
@@ -818,7 +835,7 @@ def score_plot(
             adata.uns["dropkick_thresholds"][metrics[0]]["thresh"], np.ndarray
         ):
             [
-                plt.axvline(_x, linestyle="--", color="k")
+                plt.axvline(_x, linestyle="--", color="k", linewidth=2)
                 for _x in adata.uns["dropkick_thresholds"][metrics[0]]["thresh"]
             ]
         else:
@@ -826,6 +843,7 @@ def score_plot(
                 adata.uns["dropkick_thresholds"][metrics[0]]["thresh"],
                 linestyle="--",
                 color="k",
+                linewidth=2,
             )
     # change focus to y margin plot to continue threshold line
     if metrics[1] in adata.uns["dropkick_thresholds"]:
@@ -834,7 +852,7 @@ def score_plot(
             adata.uns["dropkick_thresholds"][metrics[1]]["thresh"], np.ndarray
         ):
             [
-                plt.axhline(_x, linestyle="--", color="k")
+                plt.axhline(_x, linestyle="--", color="k", linewidth=2)
                 for _x in adata.uns["dropkick_thresholds"][metrics[1]]["thresh"]
             ]
         else:
@@ -842,6 +860,7 @@ def score_plot(
                 adata.uns["dropkick_thresholds"][metrics[1]]["thresh"],
                 linestyle="--",
                 color="k",
+                linewidth=2,
             )
     # add colorbar inside scatter axes
     axins1 = inset_axes(
@@ -879,6 +898,6 @@ def score_plot(
     if save_to is not None:
         if verbose:
             print("Saving score plot to {}".format(save_to))
-        g.savefig(save_to)
+        g.savefig(save_to, dpi=200)
     else:
         return g
